DECLARE FUNCTION DiskVerify% (drv%, head%, trck%, sec%, sdata$)
DECLARE FUNCTION DiskRead% (drv%, head%, trck%, sec%, sdata$)
DECLARE FUNCTION GetDiskInfo% (drv%)
DECLARE FUNCTION STLock% (drv%)
REM     ********************************************************************
REM     *
REM     *                 S T L O C K . M O D        Version 0.01
REM     *
REM     *
REM     * Checks for STLOCK protected disk in specified drive (0-based)
REM     *
REM     * RETURNS:
REM     *           -1  = No disk in drive / invalid drive / non dos disk
REM     *            0  = Disk is illegal copy 
REM     *            1  = Disk is STLOCK disk.
REM     ********************************************************************
	REM $INCLUDE: 'STLIB.BI'
	DEFINT A-Z

'       ---------------------------------------------------------------------
'        DiskRead:
'       ---------------------------------------------------------------------
	FUNCTION DiskRead (drv, head, trck, sec, sdata$)
	    quit = FALSE
	    count = 1
	    DO
	       sdata$ = SPACE$(512)
	       ret = DiskReadSector(drv, head, trck, sec, 1, sdata$)
	       IF ret <> 0 THEN
		  count = count + 1
		  IF count > 3 THEN
		     DiskRead = ret
		     quit = TRUE
		  ELSE
		     nul = DiskReset(drv)
		  END IF
	       ELSE
		  DiskRead = 0
		  quit = TRUE
	       END IF
	    LOOP WHILE quit = FALSE
	END FUNCTION

'       ---------------------------------------------------------------------
'        DiskVerify:
'       ---------------------------------------------------------------------
	FUNCTION DiskVerify (drv, head, trck, sec, sdata$)
	    quit = FALSE
	    count = 1
	    DO
	       sdata$ = SPACE$(512)
	       ret = DiskVerifySector(drv, head, trck, sec, 1, sdata$)
	       IF ret <> 0 THEN
		  count = count + 1
		  IF count > 3 THEN
		     DiskVerify = ret
		     quit = TRUE
		  ELSE
		     nul = DiskReset(drv)
		  END IF
	       ELSE
		  DiskVerify = 0
		  quit = TRUE
	       END IF
	    LOOP WHILE quit = FALSE
	END FUNCTION

'       ---------------------------------------------------------------------
'        GetDiskInfo:
'       ---------------------------------------------------------------------
	FUNCTION GetDiskInfo (drv)
	    GetDiskInfo = FALSE
	    IF DiskVerify(drv, 0, 0, 1, sd$) = 0 THEN
	       IF DiskVerify(drv, 0, 0, 15, sd$) = 0 THEN
		  DEF SEG = &H40
		  IF PEEK(&H47) = 16 THEN
		     GetDiskInfo = 144
		  ELSE
		     GetDiskInfo = 120
		  END IF
		  DEF SEG
	       ELSE
		  IF DiskVerify(drv, 1, 78, 1, sd$) = 0 THEN
		     GetDiskInfo = 720
		  ELSE
		     GetDiskInfo = 360
		  END IF
	       END IF
	    ELSE
	       GetDiskInfo = FALSE
	    END IF
	END FUNCTION

'       ---------------------------------------------------------------------
'        STLock:
'       ---------------------------------------------------------------------
	FUNCTION STLock (drv)
	    REDIM derr(8), derr$(8)
	    SELECT CASE GetDiskInfo(drv)
		   CASE 144, 120, 720
			last = 80
		   CASE 360
			last = 40
		   CASE ELSE
			STLock = -1
			EXIT FUNCTION
	    END SELECT
	    FOR outer = 1 TO 8
		antal = 0
		retry = TRUE
		DO
		   sd$ = SPACE$(512)
		   temp = DiskReadSector(drv, 1, last, outer, 1, sd$)
		   SELECT CASE temp
			  CASE 4
			       EXIT DO
			  CASE 16
			       retry = FALSE
			  CASE 0
			       retry = FALSE
			  CASE ELSE
		   END SELECT
		   IF retry = TRUE THEN
		      antal = antal + 1
		      IF antal < 3 THEN
			 nul = DiskReset(drv)
			 dt$ = SPACE$(512)
			 nul = DiskReadSector(drv, 1, 0, 1, 1, dt$)
		      ELSE
			 retry = FALSE
		      END IF
		   END IF
		LOOP WHILE retry = TRUE
		derr(outer) = temp
		derr$(outer) = LEFT$(sd$, 10)
	    NEXT outer
	    ok = TRUE
	    IF derr(1) <> 16 THEN
	       ok = FALSE
	    END IF
	    IF derr(2) <> 16 THEN
	       ok = FALSE
	    END IF
	    IF derr(4) <> 16 THEN
	       ok = FALSE
	    END IF
	    IF derr(5) <> 16 THEN
	       ok = FALSE
	    END IF
	    IF derr(8) <> 16 THEN
	       ok = FALSE
	    END IF
	    IF derr$(1) <> "9999999999" THEN
	       ok = FALSE
	    END IF
	    IF derr$(2) <> "9999999999" THEN
	       ok = FALSE
	    END IF
	    IF derr$(4) <> "9999999999" THEN
	       ok = FALSE
	    END IF
	    IF derr$(5) <> "9999999999" THEN
	       ok = FALSE
	    END IF
	    IF derr$(8) <> "9999999999" THEN
	       ok = FALSE
	    END IF
	    IF ok = FALSE THEN
	       STLock = FALSE
	    ELSE
	       STLock = TRUE
	    END IF
	END FUNCTION

